diff --git a/src/caoscrawler/sync_graph.py b/src/caoscrawler/sync_graph.py
index a7c27e51d635ab7387098ef9bf98a4df7688158c..1ff8dc3e289b094878d1bdec93098bd2b67782ef 100644
--- a/src/caoscrawler/sync_graph.py
+++ b/src/caoscrawler/sync_graph.py
@@ -130,7 +130,7 @@ class SyncGraph():
     # set an ID in _mark_missing if a node is in the uncheck list. Thus, setting the ID once
     # prevents future attempts to set the ID of the same node.
     # Also, setting an identifiable is only done when needed, i.e. there is no identifiable.
     # Note, that when ever one node is changed, we check all dependend nodes (see usage of
     # `_get_nodes_whose_identity_relies_on`) whether something should be updated. Thus, we cannot
     # miss a necessary update.
     def __init__(self, entities: list[db.Entity], identifiableAdapter: IdentifiableAdapter):
@@ -497,7 +497,7 @@ class SyncGraph():
         - marks target as missing/existing if source was marked that way
         - adds an identifiable if now possible (e.g. merging based on ID might allow create an
           identifiable when none of the two nodes hand the sufficient properties on its own before)
-        - check whether dependend nodes can now get and identifiable (the merge might have set the
+        - check whether dependent nodes can now get and identifiable (the merge might have set the
           ID such that dependen nodes can now create an identifiable)
         """
         # sanity checks
@@ -578,7 +578,7 @@ class SyncGraph():
         # - mark existing
         # - mark missing
         # - merge
-        self._add_identifiables_to_dependend_nodes(target)
+        self._add_identifiables_to_dependent_nodes(target)
 
         if self.get_equivalent(target) is not None:
             self._merge_into(target, self.get_equivalent(target))
@@ -617,7 +617,7 @@ class SyncGraph():
                                    condition=lambda val: id(val) in se_lookup,
                                    value=lambda val: se_lookup[id(val)])
 
-    def _add_identifiables_to_dependend_nodes(self, node):
+    def _add_identifiables_to_dependent_nodes(self, node):
         """ For each dependent node, we check whether this allows to create an identifiable """
         for other_node in self._get_nodes_whose_identity_relies_on(node):
             if self._identifiable_is_needed(other_node):
@@ -635,7 +635,7 @@ class SyncGraph():
         # - mark existing
         # - mark missing
         # - merge
-        self._add_identifiables_to_dependend_nodes(node)
+        self._add_identifiables_to_dependent_nodes(node)
         # For each dependent node, we set the ID to None (missing)
         # (None is the default second argument of set_id_of_node.)
         for other_node in self._get_nodes_whose_identity_relies_on(node):
@@ -655,4 +655,4 @@ class SyncGraph():
         # - mark existing
         # - mark missing
         # - merge
-        self._add_identifiables_to_dependend_nodes(node)
+        self._add_identifiables_to_dependent_nodes(node)
@@ -130,7 +130,7 @@ class SyncGraph():
     # prevents future attempts to set the ID of the same node.
     # Also, setting an identifiable is only done when needed, i.e. there is no identifiable.
-    # Note, that when ever one node is changed, we check all dependend nodes (see usage of
+    # Note, that when ever one node is changed, we check all dependent nodes (see usage of
     # `_get_nodes_whose_identity_relies_on`) whether something should be updated. Thus, we cannot
     # miss a necessary update.